# --8<--8<--8<--8<--
#
# Copyright (C) 2006 Smithsonian Astrophysical Observatory
#
# This file is part of yaxx
#
# yaxx is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# yaxx is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the 
#       Free Software Foundation, Inc. 
#       51 Franklin Street, Fifth Floor
#       Boston, MA  02110-1301, USA
#
# -->8-->8-->8-->8--

package Yaxx;
use strict;
use warnings;

##****************************************************************************
sub get_src_reg {
#
# Determine the extraction region for this source.  
# Use the 'x' and 'y' values.
#  
#     *** This is a placeholder for now ****
#
# Updates self-> src_reg, rad
##****************************************************************************
    my $self = shift;

    # Look for a customized version
	# Define the default source extraction region
    $self->src_reg( sprintf "circle(%.2f,%.2f,%.2f)", $self->X, $self->Y, $self->rad );

    return 1;				# Success
}

##****************************************************************************
sub make_reg_files {
##****************************************************************************
    my $self = shift;

    my $src_file = $self->file('src');
    my $bkg_file = $self->file('bkg');
    
    return 1 if (-r $src_file and -r $bkg_file);

    # Use dmcoords to find the chip boundaries
    my $chip = $self->ccdid;
    $chip = "acis-$chip" if ($chip =~ /^\d+$/);
    $self->DMcoord_set( chip => $chip );
    message(3, "Using chip = acis-". $self->ccdid ."\n");
    my @out = $self->DMcoord_coords( chip => (1,1),
				     chip => (1,1024),
				     chip => (1024,1024),
				     chip => (1024,1) );
    my $chip_reg = sprintf("polygon(%.2f,%.2f,%.2f,%.2f,%.2f,%.2f,%.2f,%.2f)",
			   $out[0]->{sky}->{x},$out[0]->{sky}->{'y'},
			   $out[1]->{sky}->{x},$out[1]->{sky}->{'y'},
			   $out[2]->{sky}->{x},$out[2]->{sky}->{'y'},
			   $out[3]->{sky}->{x},$out[3]->{sky}->{'y'});

    unless (-r $src_file) {
	message(3, "Creating src.reg for source ".$self->srcid."\n");
	open SRC, "> $src_file" or do {
	    message(1, "ERROR - could not open src region $src_file\n");
	    return;
	};
	my $src_reg = sprintf "circle(%.2f,%.2f,%.2f)", $self->X, $self->Y, $self->rad;
	print SRC "# Region file format: DS9 version 3.0\n";
	print SRC "$chip_reg & $src_reg\n";
	close SRC;
    }

    unless (-r $bkg_file) {
	open BKG, "> $bkg_file" or do {
	    message(1, "ERROR - could not open bkg region $bkg_file\n");
	    return;
	};
	print BKG "# Region file format: DS9 version 3.0\n";
	printf BKG ("$chip_reg & annulus(%.2f,%.2f,%.2f,%.2f)\n",
		    $self->X, $self->Y, $self->rad + $self->bgd_ann_sep,
		    $self->rad + $self->bgd_ann_sep + $self->bgd_ann_wid);

	foreach my $bkg (values %{$Yaxx::Bkg{ $self->obsid }}) {
	    my $bkg_reg = sprintf "circle(%.2f,%.2f,%.2f)", $bkg->X, $bkg->Y, $bkg->rad;
	    print BKG "-$bkg_reg\n";
	}
	close BKG;
    }

    1;
}

1;
